#! /usr/bin/env python

"""PSF year [timezone] ...

Display the start times of PSF Board meetings for the given year, in the
given timezones.  The Eastern time is always shown.
"""

from datetime import datetime
from dateutil import TUESDAY, weekday_of_month

from US import Eastern, Central, Mountain, Pacific
from EU import UTC, London, Amsterdam

alltzs = {'Eastern': Eastern,
          'Central': Central,
          'Mountain': Mountain,
          'Pacific': Pacific,
          'UTC': UTC,
          'London': London,
          'Amsterdam': Amsterdam,
         }

# A vector of 12 datetimes, all in Eastern.
def psf_times_for_a_year(year):
    # 1pm Eastern on the second Tuesday of the month.
    base = datetime(year, 1, 1, 13, tzinfo=Eastern)
    return [weekday_of_month(TUESDAY, base.replace(month=i), 1)
            for i in range(1, 13)]

# Eastern is always displayed first.
def display_psf_times_for_a_year(year, tzs):
    tzs = list(tzs)
    if Eastern in tzs:
        tzs.remove(Eastern)
    print "PSF Board meeting times for", year
    print
    raw = psf_times_for_a_year(year)
    # Note that the use of strftime limits us to years no earlier than
    # 1900.  This may be a problem for Guido on extended time trips.
    for date in raw:
        print date.strftime("%a %b-%d %H:%M %Z%z "),
        for tz in tzs:
            local = date.astimezone(tz)
            if local.date() == date.date():
                print local.strftime("%H:%M %Z%z "),
            else:
                # It's on a different day for them.
                local.strftime("%a %b-%d %H:%M %Z%z "),
        print

def main():
    import sys
    if len(sys.argv) < 2:
        print >> sys.stderr, "need a year argument"
        sys.exit(-1)
    year = int(sys.argv[1])
    tznames = sys.argv[2:]
    tzs = [alltzs.get(name, None) for name in tznames]
    if None in tzs:
        print >> sys.stderr, "Sorry, the only timezone names I know are", \
                             alltzs.keys()
        sys.exit(-1)
    display_psf_times_for_a_year(year, tzs)

if __name__ == '__main__':
    main()
